require_dependency "rechn_mgm_user_area/application_controller"


module RechnMgmUserArea
    DB_DATUM_FORMAT         = '%Y-%m-%dT%H:%M:%S.%L%:z'
    USER_DATUM_FORMAT       = '%d.%m.%Y %H:%M'

    class ExportsController < AuthenticatedController
        def search
            @start_date_time_string = exports_params[:start_date_time]
            @end_date_time_string = exports_params[:end_date_time]

            @start_date_time = convert_to_model_time( exports_params[:start_date_time], DB_DATUM_FORMAT).to_time
            @end_date_time   = convert_to_model_time( exports_params[:end_date_time], DB_DATUM_FORMAT).to_time
            user_id = current_user.id
            @orders = Nukleus::Document.search(user_id, @start_date_time, @end_date_time)
        end

        def generate_excel
            start_date_time_string  = exports_params[:start_date_time]
            end_date_time_string    = exports_params[:start_date_time]
            file_name = "Export_#{current_user.email}_#{start_date_time_string}-#{end_date_time_string}.xls".gsub(/\s/,'_')
            temp_file = generate_excel_file(params[:orders], file_name)
            excel_data = File.read(temp_file.path)
            send_data excel_data, :type=>'application/excel', :filename =>file_name
        end

        private
        def exports_params
            params[:export] = { start_date_time: DateTime.now.strftime(USER_DATUM_FORMAT), end_date_time: DateTime.now.strftime(USER_DATUM_FORMAT) } if params[:export].blank?
            params.require(:export).permit!
        end

        # Converts the user visible datetime (String) to the correct model format (String)
        def convert_to_model_time(view_time, output_format)
            # Correct convert string into datetime that respects time zone and daylight saving times.
            tz = ActiveSupport::TimeZone.new Rails.application.config.time_zone
            tz_datetime = tz.parse( view_time )

            # Convert datetime to correct output string.
            tz_datetime.to_datetime.strftime(output_format)
        end


        def generate_excel_file(list_of_order_ids, file_name)
            format = Spreadsheet::Format.new :color => :black, :weight => :bold, :size => 12

            book = Spreadsheet::Workbook.new
            sheet1 = book.create_worksheet
            sheet1.row(0).push "Datum", "Zieladresse"
            2.times { |i| sheet1.row(0).set_format(i, format) }

            sheet1.row(0).default_format = Spreadsheet::Format.new :color => :black, :size => 12

            list_of_order_ids.split(",").each_with_index do |o_id, index|
                o = Nukleus::Document.where(id: o_id).first
                next if o.nil?

                sheet1.row(index + 1).push o.updated_at.strftime(USER_DATUM_FORMAT), Nukleus::Document::address_of_order(o)
            end

            temp_file = Tempfile.new(file_name)

            book.write temp_file.path

            # Return the temp_file
            temp_file
        end

    end
end
